AppController class

A Controller for the 'app level'.

Inheritance
Implemented types

Constructors

AppController([StateMVC<StatefulWidget>? state])
Optionally supply a 'State' object to be linked to this State Controller.

Properties

dataObject ↔ Object?
This is of type Object allowing you to propagate any class object you wish down the widget tree.
getter/setter pairinherited
errorMsg → String
Simply display the error.
no setterinherited
hasError → bool
Indicate if the app is 'in error.'
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inDebugger → bool
Determines if running in an IDE or in production. Returns true if the App is under in the Debugger and not production.
no setterinherited
inError → bool
Indicate if app is 'in error.'
no setterinherited
keyId → String
A unique key is assigned to all State Controllers, State objects, and listeners. Used in large projects to separate objects into teams.
no setterinherited
lastContext → BuildContext?
Returns the 'latest' context in the App.
no setterinherited
rootState → AppStateMVC<AppStatefulWidgetMVC>?
Returns the 'first' StateMVC object in the App
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → StateMVC<StatefulWidget>?
The current StateMVC object.
no setterinherited
stateMVC → StateMVC<StatefulWidget>?
The current StateMVC object from mvc_application/view.dart
no setterinherited
states → Set<StateMVC<StatefulWidget>>
Return a 'copy' of the Set of State objects.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addState(StateMVC<StatefulWidget>? state) → String
Associate this Controller to the specified State object to use that State object's functions and features. Returns that State object's unique identifier.
inherited
afterListener(String key) → StateListener?
Retrieve the 'after' listener by its unique key.
inherited
beforeListener(String key) → StateListener?
Retrieve the 'before' listener by its unique key.
inherited
buildInherited() → void
Rebuild the InheritedWidget of the 'closes' InheritedStateMVC object if any.
inherited
deactivate() → void
The framework calls this method whenever it removes this StateMVC object from the tree.
inherited
dependOnInheritedWidget(BuildContext? context) → bool
Link a widget to a InheritedWidget
inherited
detachedLifecycleState() → void
Either be in the progress of attaching when the engine is first initializing or after the view being destroyed due to a Navigator pop.
inherited
didChangeAccessibilityFeatures() → void
Called when the system changes the set of active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeDependencies() → void
Called when this StateMVC object is first created immediately after initState. Otherwise called only if this State object's Widget is a dependency of InheritedWidget.
inherited
didChangeLocale(Locale locale) → void
Called when the system tells the app that the user's locale has changed.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() → Future<bool>
Called when the system tells the app to pop the current route. For example, on Android, this is called when the user presses the back button.
inherited
didPushRoute(String route) → Future<bool>
Called when the host tells the app to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) → Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didUpdateWidget(StatefulWidget oldWidget) → void
Override this method to respond when the StatefulWidget is recreated.
inherited
dispose() → void
The framework calls this method when this StateMVC object will never build again. Note: THERE IS NO GUARANTEE THIS METHOD WILL RUN in the Framework.
inherited
getError([dynamic error]) → Exception?
Return the 'last' error if any.
inherited
inactiveLifecycleState() → void
The application is in an inactive state and is not receiving user input.
inherited
initApp() → void
Initialize any immediate 'none time-consuming' operations at the very beginning.
initAsync() → Future<bool>
Used to complete asynchronous operations
initState() → void
The framework will call this method exactly once. Only when the StateMVC object is first created.
inherited
listControllers(List<String> keys) → List<ControllerMVC?>
Return a List of Controllers specified by key id.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
For those accustom to the 'Provider' approach.
inherited
ofState<T extends State<StatefulWidget>>() → T?
Retrieve the State object by type Returns null if not found
inherited
onAsyncError(FlutterErrorDetails details) → bool
Supply an 'error handler' routine if something goes wrong in the corresponding initAsync() routine.
onConnectivityChanged(ConnectivityResult result) → void
If the device's connectivity changes.
override
onError(FlutterErrorDetails details) → void
The 'App Level' Error Handler. Override if you like to customize your error handling.
pausedLifecycleState() → void
The application is not currently visible to the user, not responding to user input, and running in the background.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
rebuild() → void
Allow for a more accurate description
inherited
refresh() → void
Allows external classes to 'refresh' or 'rebuild' the widget tree.
inherited
resumedLifecycleState() → void
The application is visible and responding to user input.
inherited
setState(VoidCallback fn) → void
Provide the setState() function to external actors
inherited
stateOf<T extends StatefulWidget>() → StateMVC<StatefulWidget>?
Retrieve the State object by its StatefulWidget.Returns null if not found
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited