IOSNotificationAttachment class

Represents an attachment for an iOS notification.

Constructors

IOSNotificationAttachment(String filePath, {String? identifier})
Constructs an instance of IOSNotificationAttachment.
const

Properties

filePath → String
The local file path to the attachment.
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
The unique identifier for the attachment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited