Importance class

The available importance levels for Android notifications.

Required for Android 8.0 or newer.

Annotations

Constructors

Importance(int value)
Constructs an instance of Importance.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The integer representation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

values → List<Importance>
All the possible values for the Importance enumeration.
no setter

Constants

defaultImportance → const Importance
Default.
high → const Importance
High.
low → const Importance
Low.
max → const Importance
Max.
min → const Importance
Min.
none → const Importance
None.
unspecified → const Importance
Unspecified