MacOSNotificationDetails class

Configures notification details specific to macOS.

Constructors

MacOSNotificationDetails({bool? presentAlert, bool? presentBadge, bool? presentSound, String? sound, int? badgeNumber, List<MacOSNotificationAttachment>? attachments, String? subtitle, String? threadIdentifier})
Constructs an instance of MacOSNotificationDetails.
const

Properties

attachments → List<MacOSNotificationAttachment>?
Specifies the list of attachments included with the notification.
final
badgeNumber → int?
Specify the number to display as the app icon's badge when the notification arrives.
final
hashCode → int
The hash code for this object.
no setterinherited
presentAlert → bool?
Display an alert when the notification is triggered while app is in the foreground.
final
presentBadge → bool?
Apply the badge value when the notification is triggered while app is in the foreground.
final
presentSound → bool?
Play a sound when the notification is triggered while app is in the foreground.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sound → String?
Specifies the name of the file to play for the notification.
final
subtitle → String?
Specifies the secondary description.
final
threadIdentifier → String?
Specifies the thread identifier that can be used to group notifications together.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited