InstallFile class

Introduces a 'install file' unique to the app.

Constructors

InstallFile()

Properties

hashCode → int
The hash code for this object.
no setterinherited
justInstalled → bool
Indicate if this is the 'first' install of the app.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

sID ↔ String?
The unique Id cotained with the 'install file.'
getter/setter pair

Static Methods

id() → Future<String?>
Return the unique identifier for this app installation.
readInstallationFile(File installFile) → Future<String>
Returns the content of the 'install file.' Pass in a File object of the install file.
writeInstallationFile(File file) → String
Write to the 'install file.' Pass in a File object representing the install file.

Constants

FILE_NAME → const String
The name of the 'install file.'