ModelMVC class

The Model for a simple app. Incorporates an Error Handler.

Inheritance
  • Object
  • StateSetter
  • ModelMVC
  • ModelMVC
Mixed-in types

Constructors

ModelMVC([StateMVC<StatefulWidget>? state])
The Singleton Pattern is used with only one stance instantiated.
factory

Properties

dataObject ↔ Object?
This is of type Object allowing you to propagate any class object you wish down the widget tree.
getter/setter pairinherited
errorMsg → String
Simply display the error.
no setterinherited
hasError → bool
Indicate if the app is 'in error.'
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inDebugger → bool
Determines if running in an IDE or in production. Returns true if the App is under in the Debugger and not production.
no setterinherited
inError → bool
Indicate if app is 'in error.'
no setterinherited
lastContext → BuildContext?
Returns the 'latest' context in the App.
no setterinherited
rootState → AppStateMVC<AppStatefulWidgetMVC>?
Returns the 'first' StateMVC object in the App
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
states → Set<StateMVC<StatefulWidget>>
Return a 'copy' of the Set of State objects.
no setterinherited

Methods

getError([dynamic error]) → Exception?
Return the 'last' error if any.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
For those accustom to the 'Provider' approach.
inherited
ofState<T extends State<StatefulWidget>>() → T?
Retrieve the State object by type Returns null if not found
inherited
rebuild() → void
Allow for a more accurate description
inherited
refresh() → void
Allows external classes to 'refresh' or 'rebuild' the widget tree.
inherited
setState(VoidCallback fn) → void
Provide the setState() function to external actors
inherited
stateOf<T extends StatefulWidget>() → StateMVC<StatefulWidget>?
Retrieve the State object by its StatefulWidget.Returns null if not found
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

mod → ModelMVC
Allow for easy access to 'the first Model' throughout the application.
no setter