AppRoutePath class

Of course, You're free to override this class if you like

Constructors

AppRoutePath.home()
Identified as the 'home' page.
AppRoutePath.page(String? path)
Identified as a Page.
AppRoutePath.unknown([String? _path])
Indentified as an 'unknown' page.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isHomePage → bool
Indicates if it is a 'home' page.
final
isUnknown → bool
Indicates if the page is unknown.
final
path → String?
The path
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(Map<String, dynamic> json) → AppRoutePath
Returns an AppRoutePath object for a Json object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object>
Converts the AppRoutePath object as a Json object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited