AppRouterDelegate class

A delegate that configures a widget, typically a Navigator

Inheritance
Mixed-in types

Constructors

AppRouterDelegate({required Map<String, WidgetBuilder> routes, void add(VoidCallback listener)?, void remove(VoidCallback listener)?})
Provide the Map of 'Routes' as well as ADD and Remove routines.
factory

Properties

add → void Function(VoidCallback listener)?
Add a listener when the route is called.
final
currentConfiguration → AppRoutePath
Of course, You're free to override this function if you like This getter will update the current URL path
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
home ↔ WidgetBuilder
The Widget Builder to produce the home screen.
getter/setter pair
homePage ↔ Page?
Specify the 'home' Page object.
getter/setter pair
Of course, You're free to override this function if you like
no setteroverride
remove → void Function(VoidCallback listener)?
Remove a listener
final
routes → Map<String, WidgetBuilder>
The Map of specified 'routes'
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
build(BuildContext context) → Widget
Of course, You're free to override this function if you like
override
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
popRoute() → Future<bool>
Called by the Router when the Router.backButtonDispatcher reports that the operating system is requesting that the current route be popped.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setInitialRoutePath(AppRoutePath configuration) → Future<void>
Called by the Router at startup with the structure that the RouteInformationParser obtained from parsing the initial route.
inherited
setNewRoutePath(AppRoutePath configuration) → Future<void>
Of course, You're free to override this function if you like
override
setRestoredRoutePath(AppRoutePath configuration) → Future<void>
Called by the Router during state restoration.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

nextRoute(String? path) → bool
Supply the next route