Connectivity class

Discover network connectivity configurations: Distinguish between WI-FI and cellular, check WI-FI status and more.

Constructors

Connectivity()
Constructs a singleton instance of Connectivity.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
onConnectivityChanged → Stream<ConnectivityResult>
Fires whenever the connectivity state changes.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkConnectivity() → Future<ConnectivityResult>
Checks the connection status of the device.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited