CustomRaisedButton class

A Elevated button with a built-in spinner Used to convey an on-going process that completes with an enabled button.

Inheritance
Available extensions
Annotations

Constructors

CustomRaisedButton({Key? key, bool? loading, required VoidCallback? onPressed, VoidCallback? onLongPress, ValueChanged<bool>? onHover, ValueChanged<bool>? onFocusChange, ButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, required Widget? child})
A constructor that takes in Elevated buttons properties.
const

Properties

autofocus → bool?
If True, this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
child → Widget?
Typically the button's label.
final
clipBehavior → Clip?
Different ways to clip a widget's content.
final
focusNode → FocusNode?
To obtain the keyboard focus and to handle keyboard events.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → bool?
A flag when True will enable the button.
final
marginZero → Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
onFocusChange → ValueChanged<bool>?
Optional. Called when the focus changes.
final
onHover → ValueChanged<bool>?
Optional. Called when a pointer enters or exits the button response area.
final
onLongPress → VoidCallback?
Optional 'Long Press' Callback function
final
onPressed → VoidCallback?
Optional Callback function
final
paddingZero → Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliverBox → Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
style → ButtonStyle?
Customizes this button's appearance.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buttonSpinner(BuildContext context) → Widget
Displays a Processing Indicator.
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited