DataFields<T> class

Comprehensive Data Field Class

Constructors

DataFields()

Properties

errorText → String?
A collection of errors returned by the FormField.validator
no setter
field ↔ Map<dynamic, Map<String, FieldWidgets<T>>>
A map of 'field' objects
getter/setter pairinherited
hasError → bool
True if this field has any validation errors.
no setter
hashCode → int
The hash code for this object.
no setterinherited
items → List<Map<String, dynamic>>
List of the actual data fields.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Map<String, dynamic> rec) → Future<bool>
addField(FormFieldState field) → void
Add a FormFieldState object.
delete(Map<String, dynamic> rec) → Future<bool>
fieldErrors() → String
Any errors from every FormField that is a descendant of this Form.
fillRecords(List<Map<String, dynamic>> fieldData) → void
inherited
linkForm(Widget child) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query() → Future<List<Map<String, dynamic>>>
Retrieve the to-do items from the database
inherited
removeField(FormFieldState field) → void
Remove a FormFieldState object.
retrieve() → Future<List<Map<String, dynamic>>>
Retrieve the data fields from the data source into a List of Maps.
save(Map<String, dynamic> rec) → Future<bool>
The save record routine.
saveForm() → bool
toString() → String
A string representation of this object.
inherited
undo(Map<String, dynamic> rec) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited