DialogBox class

Display an extensive widget to a dialogue window.

Mixed-in types

Constructors

DialogBox({String? title, Option? button01, Option? button02, VoidCallback? press01, VoidCallback? press02, bool? switchButtons, List<Widget>? body, List<Widget>? actions, bool? barrierDismissible = false})
Supply the Dialog window's buttons and Callback routines.

Properties

actions → List<Widget>?
The Dialog window's title.
final
barrierDismissible → bool?
Whether or not the Dialog window disables the rest of the interface or not.
final
body → List<Widget>?
The Dialog window's title.
final
button01 ↔ Option?
First button option
getter/setter pairinherited
button02 ↔ Option?
Second button option
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
press01 ↔ VoidCallback?
First button's callback function
getter/setter pairinherited
press02 ↔ VoidCallback?
Second button's callback function
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
switchButtons ↔ bool?
Boolean flag to switch display order of buttons.
getter/setter pairinherited
title → String?
The Dialog window's title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show({String? title, Option? button01, Option? button02, VoidCallback? press01, VoidCallback? press02, bool? switchButtons, String? msg, List<Widget>? body, List<Widget>? actions, bool? barrierDismissible}) → Future<void>
Display the Dialog window.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited