DialogOptions mixin

A mixin to work with the class DialogBox or can be assigned to any class involving two buttons and their callback routines.

Mixin applications

Properties

button01 ↔ Option?
First button option
getter/setter pair
button02 ↔ Option?
Second button option
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
press01 ↔ VoidCallback?
First button's callback function
getter/setter pair
press02 ↔ VoidCallback?
Second button's callback function
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
switchButtons ↔ bool?
Boolean flag to switch display order of buttons.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited