FieldWidgets<T> class

The base 'Field' Widget class

Inheritance
Mixed-in types

Constructors

FieldWidgets({Object? key, T? object, String? label, dynamic value, dynamic type, TextEditingController? controller, String? initialValue, FocusNode? focusNode, InputDecoration? inputDecoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, TextSpan? textSpan, TextStyle? style, TextAlign? textAlign, bool? autofocus, bool? obscureText, bool? autocorrect, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines, int? maxLength, ValueChanged<String>? changed, VoidCallback? editingComplete, ValueChanged<String>? fieldSubmitted, FormFieldSetter<String>? saved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool? enabled, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, double? textScaleFactor, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Widget? leading, Widget? title, Widget? subtitle, Widget? trailing, bool? isThreeLine, bool? dense, VisualDensity? visualDensity, ShapeBorder? shape, Color? selectedColor, Color? iconColor, Color? textColor, EdgeInsetsGeometry? contentPadding, GestureTapCallback? tap, GestureLongPressCallback? longPress, MouseCursor? mouseCursor, bool? selected, Color? focusColor, Color? hoverColor, Color? tileColor, Color? selectedTileColor, Widget? secondary, ListTileControlAffinity? controlAffinity, Color? backgroundColor, ImageProvider<Object>? backgroundImage, ImageProvider<Object>? foregroundImage, ImageErrorListener? onBackgroundImageError, ImageErrorListener? onForegroundImageError, Color? foregroundColor, double? radius, double? minRadius, double? maxRadius, Widget? child, Widget? background, Widget? secondaryBackground, VoidCallback? resize, DismissDirectionCallback? dismissed, DismissDirection? direction, Duration? resizeDuration, Map<DismissDirection, double>? dismissThresholds, Duration? movementDuration, double? crossAxisEndOffset, ValueChanged<bool>? toggle, Color? activeColor, bool? tristate, MaterialTapTargetSize? materialTapTargetSize})
Constructor supplies all the options depending on the field Widget.

Properties

activeColor ↔ Color?
getter/setter pair
autocorrect ↔ bool?
Whether to enable autocorrection.
getter/setter pair
autofillHints ↔ Iterable<String>?
A list of strings that helps the autofill service identify the type of this text input.
getter/setter pair
autofocus ↔ bool?
Whether this text field should focus itself if nothing else is already focused.
getter/setter pair
autovalidateMode ↔ AutovalidateMode?
Used to enable/disable this form field auto validation and update its error text.
getter/setter pair
background ↔ Widget?
getter/setter pair
backgroundColor ↔ Color?
todo: CircleAvatar The color with which to fill the circle.
getter/setter pair
backgroundImage ↔ ImageProvider<Object>?
The background image of the circle. Changing the background image will cause the avatar to animate to the new image.
getter/setter pair
buildCounter ↔ InputCounterWidgetBuilder?
getter/setter pair
changed ↔ ValueChanged<String>?
getter/setter pair
checkbox → Checkbox
no setter
checkboxListTile → CheckboxListTile
no setter
child ↔ Widget?
todo: Dismissible
getter/setter pair
circleAvatar → CircleAvatar
no setter
contentPadding ↔ EdgeInsetsGeometry?
The tile's internal padding.
getter/setter pair
controlAffinity ↔ ListTileControlAffinity?
Where to place the control relative to the text.
getter/setter pair
controller ↔ TextEditingController?
todo: TextFormField
getter/setter pair
crossAxisEndOffset ↔ double?
getter/setter pair
defaultTextStyle → DefaultTextStyle
no setter
dense ↔ bool?
Whether this list tile is part of a vertically dense list.
getter/setter pair
direction ↔ DismissDirection?
getter/setter pair
dismissed ↔ DismissDirectionCallback?
getter/setter pair
dismissible → Dismissible
no setter
dismissThresholds ↔ Map<DismissDirection, double>?
getter/setter pair
editingComplete ↔ VoidCallback?
getter/setter pair
enabled ↔ bool?
If false the text field is "disabled": it ignores taps and its decoration is rendered in grey.
getter/setter pair
fieldSubmitted ↔ ValueChanged<String>?
getter/setter pair
focusColor ↔ Color?
The color for the tile's Material when it has the input focus.
getter/setter pair
focusNode ↔ FocusNode?
To obtain the keyboard focus and to handle keyboard events.
getter/setter pair
foregroundColor ↔ Color?
The default text color for text in the circle.
getter/setter pair
foregroundImage ↔ ImageProvider<Object>?
The foreground image of the circle.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hoverColor ↔ Color?
The color for the tile's Material when a pointer is hovering over it.
getter/setter pair
iconColor ↔ Color?
Defines the default color for leading and trailing icons.
getter/setter pair
id ↔ dynamic
getter/setter pairinherited
initialValue ↔ String?
The current text being edited.
getter/setter pair
inputDecoration ↔ InputDecoration?
The border, labels, icons, and styles used to decorate a Material Design text field.
getter/setter pair
inputFormatters ↔ List<TextInputFormatter>?
Optional input validation and formatting overrides.
getter/setter pair
isThreeLine ↔ bool?
Whether this list tile is intended to display three lines of text.
getter/setter pair
items ↔ Iterable<DataFieldItem>?
getter/setter pair
key → String?
no setter
keyboardAppearance ↔ Brightness?
The appearance of the keyboard. This setting is only honored on iOS devices.
getter/setter pair
keyboardType ↔ TextInputType?
The type of information for which to optimize the text input control.
getter/setter pair
label ↔ String?
getter/setter pairinherited
leading ↔ Widget?
todo: ListTile A widget to display before the title.
getter/setter pair
listItems → ListItems<T>
no setter
listTile → Widget
no setter
locale ↔ Locale?
getter/setter pair
longPress ↔ VoidCallback?
Called when the user long-presses on this list tile.
getter/setter pair
materialTapTargetSize ↔ MaterialTapTargetSize?
getter/setter pair
maxLength ↔ int?
The maximum string length that can be entered into the TextField.
getter/setter pair
maxLengthEnforcement ↔ MaxLengthEnforcement?
Determines how the maxLength limit should be enforced.
getter/setter pair
maxLines ↔ int?
The maximum number of lines for the text to span, wrapping if necessary.
getter/setter pair
maxRadius ↔ double?
getter/setter pair
minRadius ↔ double?
getter/setter pair
mouseCursor ↔ MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
getter/setter pair
movementDuration ↔ Duration?
getter/setter pair
object ↔ T?
getter/setter pair
obscureText ↔ bool?
Whether to hide the text being edited (e.g., for passwords).
getter/setter pair
onBackgroundImageError ↔ ImageErrorListener?
An optional error callback for errors emitted when loading
getter/setter pair
onForegroundImageError ↔ ImageErrorListener?
An optional error callback for errors emitted when loading
getter/setter pair
overflow ↔ TextOverflow?
How visual overflow should be handled.
getter/setter pair
radius ↔ double?
The size of the avatar, expressed as the radius (half the diameter).
getter/setter pair
resize ↔ VoidCallback?
getter/setter pair
resizeDuration ↔ Duration?
getter/setter pair
richText → Text
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saved ↔ FormFieldSetter<String>?
getter/setter pair
scrollPadding ↔ EdgeInsets?
getter/setter pair
scrollPhysics ↔ ScrollPhysics?
getter/setter pair
secondary ↔ Widget?
todo: CheckboxListTile A widget to display on the opposite side of the tile from the checkbox.
getter/setter pair
secondaryBackground ↔ Widget?
getter/setter pair
selected ↔ bool?
If this tile is also enabled then icons and text are rendered with the same color.
getter/setter pair
selectedColor ↔ Color?
Defines the color used for icons and text when the list tile is selected.
getter/setter pair
selectedTileColor ↔ Color?
Defines the background color of ListTile when selected is true.
getter/setter pair
semanticsLabel ↔ String?
An alternative semantics label for this text.
getter/setter pair
shape ↔ ShapeBorder?
Defines the tile's 'InkWell.customBorder' and Ink.decoration shape.
getter/setter pair
softWrap ↔ bool?
If the softWrap is true or null, the glyph causing overflow, and those that follow, will not be rendered. Otherwise, it will be shown with the given overflow option.
getter/setter pair
state → StateMVC<StatefulWidget>?
The 'current' State object.
no setterinherited
style ↔ TextStyle?
Describing how to format and paint text.
getter/setter pair
subtitle ↔ Widget?
Additional content displayed below the title.
getter/setter pair
tap ↔ VoidCallback?
Called when the user taps this list tile.
getter/setter pair
text → Text
no setter
textAlign ↔ TextAlign?
Whether and how to align text horizontally.
getter/setter pair
textCapitalization ↔ TextCapitalization?
Configures how the platform keyboard will select an uppercase or lowercase keyboard.
getter/setter pair
textColor ↔ Color?
Defines the default color for the title and subtitle.
getter/setter pair
textDirection ↔ TextDirection?
getter/setter pair
textFormField → Widget
no setter
textHeightBehavior ↔ TextHeightBehavior?
Specifies how the height multiplier is applied to ascent of the first line and the descent of the last line.
getter/setter pair
textInputAction ↔ TextInputAction?
An action the user has requested the text input control to perform.
getter/setter pair
textScaleFactor ↔ double?
The number of font pixels for each logical pixel.
getter/setter pair
textSpan ↔ TextSpan?
todo: Text
getter/setter pair
textWidthBasis ↔ TextWidthBasis?
Defines how to measure the width of the rendered text.
getter/setter pair
tileColor ↔ Color?
Defines the background color of ListTile when selected is false.
getter/setter pair
title ↔ Widget?
The primary content of the list tile.
getter/setter pair
toggle ↔ ValueChanged<bool>?
getter/setter pair
toMap → Map<String, dynamic>
no setterinherited
trailing ↔ Widget?
A widget to display after the title.
getter/setter pair
tristate ↔ bool?
getter/setter pair
type ↔ dynamic
getter/setter pairinherited
validator ↔ FormFieldValidator<String>?
getter/setter pair
value ↔ dynamic
getter/setter pairinherited
visualDensity ↔ VisualDensity?
Defines how compact the list tile's layout will be.
getter/setter pair

Methods

dispose() → bool
Call this in the State object's dispose function.
inherited
initials(String fullName) → String
initState(StateMVC<StatefulWidget>? state) → void
Call this in the State object's initState() function.
inherited
isChanged({bool? changed}) → bool
keys({String? id, String? label, String? value, String? type}) → void
Assigns the names for the 'label' field and the 'value' field.
inherited
mapItems<U extends FieldWidgets<T>>(String key, List<DataFieldItem>? items, U create(DataFieldItem dataItem), [U? itemsObj]) → List<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBackground() → Widget
onChanged(String? value) → void
onCheckBox({bool? value, ValueChanged<bool>? onChanged, Color? activeColor, bool? tristate, MaterialTapTargetSize? materialTapTargetSize}) → Checkbox
onCheckboxListTile({bool? value, ValueChanged<bool>? onChanged, Color? activeColor, Widget? title, Widget? subtitle, bool? isThreeLine, bool? dense, Widget? secondary, bool? selected, ListTileControlAffinity? controlAffinity}) → CheckboxListTile
onChild() → Widget
Override to place a different child in the Dismissible.
onCircleAvatar({Color? backgroundColor, Color? foregroundColor, ImageProvider<Object>? backgroundImage, double? radius, double? minRadius, double? maxRadius}) → CircleAvatar
onDefaultTextStyle({TextStyle? style, TextAlign? textAlign, bool? softWrap, TextOverflow? overflow, int? maxLines, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Widget? child}) → DefaultTextStyle
onDismissed(DismissDirection direction) → void
Override to place here what happens when the field is dismissed.
onDismissible({Widget? child, Widget? background, Widget? secondaryBackground, VoidCallback? resize, DismissDirectionCallback? dismissed, DismissDirection? direction, Duration? resizeDuration, Map<DismissDirection, double>? dismissThresholds, Duration? movementDuration, double? crossAxisEndOffset}) → Dismissible
onDropItems() → List<String>?
Allow a subclass supply the drop items.
one2Many<U extends FieldWidgets<T>>(U create()) → void
Convert a list item into separate objects.
onEditingComplete() → void
Override to perform what happens when finished editing the field.
onFieldSubmitted(String v) → void
Override to perform what happens when the field value is submitted.
onLeading() → Widget?
onListItems({String? title, List<FieldWidgets<T>>? items, MapItemFunction? mapItem, GestureTapCallback? onTap, ValueChanged<String?>? onChanged, List<String>? dropItems}) → ListItems<T>
onListTile({Widget? leading, Widget? title, Widget? subtitle, Widget? trailing, bool? isThreeLine, bool? dense, VisualDensity? visualDensity, ShapeBorder? shape, Color? selectedColor, Color? iconColor, Color? textColor, EdgeInsetsGeometry? contentPadding, bool? enabled, GestureTapCallback? tap, GestureLongPressCallback? longPress, bool? selected}) → Widget
onLongPress() → void
Override to place what happens when the field is 'long' pressed.
onResize() → void
Override to place what happens when the field is resized.
onRichText({TextSpan? textSpan, TextStyle? style, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, double? textScaleFactor, int? maxLines, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior}) → Text
onSaved(dynamic v) → void
What happens when the field is saved?
onSecondary() → Widget?
A widget to display on the opposite side of the tile from the checkbox.
onSecondaryBackground() → Widget?
Override to provide a secondary background.
onSubtitle() → Widget
Override to produce a subtitle.
onTap() → void
Override to place what happens when the field is tapped.
onText({TextSpan? textSpan, TextStyle? style, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, double? textScaleFactor, int? maxLines, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior}) → Text
onTextFormField({TextEditingController? controller, String? initialValue, FocusNode? focusNode, InputDecoration? inputDecoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, TextStyle? style, TextAlign? textAlign, bool? autofocus, bool? obscureText, bool? autocorrect, bool? autovalidate, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines, int? maxLength, VoidCallback? editingComplete, ValueChanged<String>? fieldSubmitted, FormFieldSetter<String>? saved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool? enabled, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode, bool create = false}) → TextFormField
onTitle() → Widget
onToggle({bool? value}) → void
onTrailing() → Widget?
onValidator(String? v) → String?
Override to return a different field value when validating. Return null if validated. Error message if not.
popState() → bool
Pop out the last State object from the Set.
inherited
pushState([StateMVC<StatefulWidget>? state]) → bool
Add the optional State object to the Set
inherited
rebuild() → bool
Notify the framework of a rebuild in the next scheduled frame
inherited
refresh() → bool
Notify the framework of a rebuild in the next scheduled frame
inherited
setState(VoidCallback fn) → bool
Notify the framework of a rebuild in the next scheduled frame
inherited
TextFormField({TextEditingController? controller, String? initialValue, FocusNode? focusNode, InputDecoration? inputDecoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, TextStyle? style, TextAlign? textAlign, bool? autofocus, bool? obscureText, bool? autocorrect, bool? autovalidate, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines, int? maxLength, ValueChanged<String>? changed, VoidCallback? editingComplete, ValueChanged<String>? fieldSubmitted, FormFieldSetter<String>? saved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool? enabled, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode}) → Widget
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited