GetStringUtils extension

on

Properties

camelCase → String?

Available on String, provided by the GetStringUtils extension

Return this String in camelcase format.
no setter
capitalize → String?

Available on String, provided by the GetStringUtils extension

Return this String all capitalized.
no setter
capitalizeFirst → String?

Available on String, provided by the GetStringUtils extension

Return this String starting with a capital letter.
no setter
isAlphabetOnly → bool

Available on String, provided by the GetStringUtils extension

Is this String all alphabetical characters?
no setter
isAPKFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String is an APK file?
no setter
isAudioFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String an Audio file?
no setter
isBinary → bool

Available on String, provided by the GetStringUtils extension

Is this String a Binary character string?
no setter
isBool → bool

Available on String, provided by the GetStringUtils extension

Is this String a boolean value?
no setter
isCnpj → bool

Available on String, provided by the GetStringUtils extension

Is this String is Cnpj character string?
no setter
isCpf → bool

Available on String, provided by the GetStringUtils extension

Is this String is a Cpf character string?
no setter
isCurrency → bool

Available on String, provided by the GetStringUtils extension

Is this String a currency?
no setter
isDateTime → bool

Available on String, provided by the GetStringUtils extension

Is this String a DateTime value?
no setter
isDocumentFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String a Word file?
no setter
isEmail → bool

Available on String, provided by the GetStringUtils extension

Is this String an Email?
no setter
isExcelFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String an Excel file?
no setter
isHexadecimal → bool

Available on String, provided by the GetStringUtils extension

Is this String an Hexadecimal character string?
no setter
isHTMLFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String an HTML file?
no setter
isImageFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String an Image file?
no setter
isIPv4 → bool

Available on String, provided by the GetStringUtils extension

Is this String a IPv4 character string?
no setter
isIPv6 → bool

Available on String, provided by the GetStringUtils extension

Is this String a IPv6 character string?
no setter
isMD5 → bool

Available on String, provided by the GetStringUtils extension

Is this String
no setter
isNum → bool

Available on String, provided by the GetStringUtils extension

Is this String a number?
no setter
isNumericOnly → bool

Available on String, provided by the GetStringUtils extension

Is this String all numeric characters?
no setter
isPalindrom → bool

Available on String, provided by the GetStringUtils extension

Is this String a Palindrom?
no setter
isPassport → bool

Available on String, provided by the GetStringUtils extension

This string is a Passport value?
no setter
isPDFFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String is an PDF file?
no setter
isPhoneNumber → bool

Available on String, provided by the GetStringUtils extension

Is this String a phone number?
no setter
isPPTFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String an PPT file?
no setter
isSHA1 → bool

Available on String, provided by the GetStringUtils extension

Is this String a SHA1 character string?
no setter
isSHA256 → bool

Available on String, provided by the GetStringUtils extension

Is this String a SHA256 character string?
no setter
isTxtFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String a txt file?
no setter
isURL → bool

Available on String, provided by the GetStringUtils extension

Is this String a URL?
no setter
isVectorFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String a Vector?
no setter
isVideoFileName → bool

Available on String, provided by the GetStringUtils extension

Is this String a Video file?
no setter
paramCase → String?

Available on String, provided by the GetStringUtils extension

Return this String to param case format.
no setter
removeAllWhitespace → String

Available on String, provided by the GetStringUtils extension

Return this String with no blanks.
no setter

Methods

createPath([Iterable? segments]) → String

Available on String, provided by the GetStringUtils extension

Return this String as a path with optional segments inserted.
isCaseInsensitiveContains(String b) → bool

Available on String, provided by the GetStringUtils extension

Does the provided string contained in this string?
isCaseInsensitiveContainsAny(String b) → bool

Available on String, provided by the GetStringUtils extension

Does any of the string value contained in this string?
numericOnly({bool firstWordOnly = false}) → String

Available on String, provided by the GetStringUtils extension

Return this String with only numbers.