HomeBarButton class

The pre-defined 'Home' Bottom Bar Button

Inheritance

Constructors

HomeBarButton({VoidCallback? onPressed})
Optionally supply an 'onPressed' routine.

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
Optionally supply an icon for the button.
finalinherited
onPressed → VoidCallback?
Optionally supply the button's 'onPressed' routine.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
Optionally supply the Button's label.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited