InheritedStates class

Builds a InheritedWidget.

It's instantiated in a standalone widget so its setState() call will only rebuild InheritedWidget and consequently any of its dependents, instead of rebuilding the app's entire widget tree.

Constructors

InheritedStates()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

add(InheritedWidget? func(), {Key? key}) → InheritedStateWidget
Returns an Object containing InheritedWidget and its build function
has<T extends InheritedWidget>() → bool
If the widget has been mounted with its State object
inheritWidget<T extends InheritedWidget>(BuildContext context, {Object? aspect}) → bool
Link a widget to an InheritedWidget of type T
rebuild<T extends InheritedWidget>() → void
Calls the build() function in this Widget's State object.