MapClass class

Used to test for a Map object before attempting to access it.

Constructors

MapClass(Map<String, dynamic>? map)

Properties

hashCode → int
The hash code for this object.
no setterinherited
map → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
p(String? key) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited