Menu class abstract

Abstract class to implement the App's popup menu.

Constructors

Called to instantiate an App popup menu object.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tailItems ↔ List<PopupMenuItem>
The List of defined Popup Menu Items at the tail end of the menu.
getter/setter pair

Methods

The List of defined Popup Menu Items.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSelected(dynamic menuItem) → void
Called when a menu item is selected.
show(StateMVC<StatefulWidget> state, {String? applicationName}) → PopupMenuButton
Display the popup menu. Passed in a 'State' object and the Application's very name.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited