MsgBox class

Message Box Class

Constructors

MsgBox({required BuildContext context, String? title, String? msg, List<Widget>? body, List<Widget>? actions})
Supply a Message box
const

Properties

actions → List<Widget>?
Optional set of actions that are displayed at the bottom of the Message box.
final
body → List<Widget>?
Optional List of Widgets that take precedence over msg and will be displayed instead.
final
context → BuildContext
Requires a BuildContext
final
hashCode → int
The hash code for this object.
no setterinherited
msg → String?
Optional String as the primary message of the Message box.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Optional String to display as a title on the Message box.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show({BuildContext? context, String? title, String? msg, List<Widget>? body, List<Widget>? actions}) → Future<void>
Call to display this Message box.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited