TabButtons class

Produces a list of Tabs long the screen.

Inheritance
Available extensions

Constructors

TabButtons({Key? key, Color foregroundOn = Colors.white, Color foregroundOff = Colors.black, Color? backgroundOn = Colors.blue, Color? backgroundOff, double? height = 49, ScrollPhysics? physics, double? padding = 6, double borderRadius = 7, int? durationOff = 75, int? durationOn = 150})
Supply the 'general appearance' of the screen's ListView

Properties

backgroundOff → Color?
inactive button's background color
final
backgroundOn → Color?
active button's background color
final
borderRadius → double
Tabs' border thickness
final
durationOff → int?
Tabs' duration off
final
durationOn → int?
Tabs' duration on.
final
foregroundOff → Color
inactive button's foreground color
final
foregroundOn → Color
active button's foreground color
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
Tabs' height
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marginZero → Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
padding → double?
Tabs' padding
final
paddingZero → Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
physics → ScrollPhysics?
Tabs' Scroll Physics
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliverBox → Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
tabView ↔ Map<Widget, Widget>
The Tabs and Views displayed on the screen.
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) → Widget

Available on Widget, provided by the WidgetPaddingX extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited