UniversalPlatform class abstract

Constructors

UniversalPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isAndroid → bool
no setter
isApple → bool
no setter
isDesktop → bool
no setter
isDesktopOrWeb → bool
no setter
isFuchsia → bool
no setter
isIOS → bool
no setter
isLinux → bool
no setter
isMacOS → bool
no setter
isMobile → bool
no setter
isWeb → bool
no setter
isWindows → bool
no setter
operatingSystem → String
no setter
value → UniversalPlatformType
no setter